/** @typedef {import('../performance-observer').Entry} Entry */
/** @typedef {import('../performance-observer').ObserverOpts} ObserverOpts */
/** @typedef {import('../performance-observer').ObserverCallback} ObserverCallback */
/**
 * Record all performance observer events in one trace.
 *
 * @param {function} cb
 * @param {{ noResource?: boolean, filterMeasure?: function, filterMarks?: function }} [opts]
 */
export function recordTrace(cb: Function, opts?: {
    noResource?: boolean | undefined;
    filterMeasure?: Function | undefined;
    filterMarks?: Function | undefined;
} | undefined): void;
export type Entry = {
    entryType: string;
    toJSON: () => any;
    name: string;
    startTime: number;
    duration: number;
    /**
     * first-input
     */
    detail?: any;
    processingStart: number;
    /**
     * largest-contentful-paint
     */
    processingEnd: number;
    element: HTMLElement;
    size: number;
    renderTime: number;
    /**
     * layout-shift
     */
    loadTime: number;
    value: number;
    lastInputTime: number;
    /**
     * resource
     */
    hadRecentInput: boolean;
    initiatorType: string;
    transferSize: number;
    encodedBodySize: number;
    /**
     * navigation
     */
    decodedBodySize: number;
    type: string;
    domContentLoadedEventEnd: number;
    responseStart: number;
    /**
     * element
     */
    loadEventEnd: number;
    identifier: string;
    intersectionRect: DOMRectReadOnly;
};
export type ObserverOpts = "navigation" | "mark" | "measure" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "paint" | "resource" | "event" | {
    type: "navigation" | "mark" | "measure" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "paint" | "resource" | "event";
    buffered?: boolean | undefined;
};
export type ObserverCallback = (entries: import("../utils").Entry[], observer: PerformanceObserver) => any;
