/**
 * Collect metrics.
 *
 * @param {(MetricType | CollectMetricOpts)[]} metricsOpts
 * @param {(metric: FcpMetric | LcpMetric | ClsMetric | FidMetric) => any} cb
 */
export function collectMetrics(metricsOpts: ("fcp" | "fid" | "lcp" | "cls" | {
    type: "fcp" | "fid" | "lcp" | "cls";
    maxTimeout?: number | undefined;
})[], cb: (metric: {
    metricType: "fcp";
    value: number;
} | {
    metricType: "fid";
    value: number;
    detail: {
        startTime: number;
        duration: number;
        processingStart: number;
        processingEnd: number;
        name: string;
    };
} | {
    metricType: "lcp";
    value: number;
    detail: {
        size: number;
        elementSelector: string | null;
    };
} | {
    metricType: "cls";
    value: number;
    detail: {
        totalEntries: number;
        sessionDuration: number;
    };
}) => any): void;
/** @param {(metric: FcpMetric) => any} cb */
export function collectFcp(cb: (metric: {
    metricType: "fcp";
    value: number;
}) => any): void;
/** @param {(metric: FidMetric) => any} cb */
export function collectFid(cb: (metric: {
    metricType: "fid";
    value: number;
    detail: {
        startTime: number;
        duration: number;
        processingStart: number;
        processingEnd: number;
        name: string;
    };
}) => any): void;
/** @param {(metric: LcpMetric) => any} cb */
export function collectLcp(cb: (metric: {
    metricType: "lcp";
    value: number;
    detail: {
        size: number;
        elementSelector: string | null;
    };
}) => any, opts?: {}): void;
/** @param {(metric: ClsMetric) => any} cb */
export function collectCls(cb: (metric: {
    metricType: "cls";
    value: number;
    detail: {
        totalEntries: number;
        sessionDuration: number;
    };
}) => any, opts?: {}): void;
/** @param {(metric: LoadMetric) => any} cb */
export function collectLoad(cb: (metric: {
    metricType: "load";
    value: number;
    detail: {
        timeToFirstByte: number;
        domContentLoaded: number;
    };
}) => any): void;
export type FcpMetric = {
    metricType: "fcp";
    value: number;
};
export type FidMetric = {
    metricType: "fid";
    value: number;
    detail: {
        startTime: number;
        duration: number;
        processingStart: number;
        processingEnd: number;
        name: string;
    };
};
export type LcpMetric = {
    metricType: "lcp";
    value: number;
    detail: {
        size: number;
        elementSelector: string | null;
    };
};
export type ClsMetric = {
    metricType: "cls";
    value: number;
    detail: {
        totalEntries: number;
        sessionDuration: number;
    };
};
export type LoadMetric = {
    metricType: "load";
    value: number;
    detail: {
        timeToFirstByte: number;
        domContentLoaded: number;
    };
};
export type MetricType = "fcp" | "fid" | "lcp" | "cls";
export type CollectMetricOpts = {
    type: "fcp" | "fid" | "lcp" | "cls";
    maxTimeout?: number | undefined;
};
