/**
 * Create performance observer.
 *
 * @param {ObserverOpts} rawOpts
 * @param {ObserverCallback} callback
 */
export function observeEntries(rawOpts: "navigation" | "mark" | "measure" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "paint" | "resource" | "event" | {
    type: "navigation" | "mark" | "measure" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "paint" | "resource" | "event";
    buffered?: boolean | undefined;
}, callback: (entries: import("./utils").Entry[], observer: PerformanceObserver) => any): PerformanceObserver;
/**
 * Get buffered entries by `type`.
 *
 * @param {EntryType} entryType
 * @return {Promise<Entry[]>}
 */
export function getEntriesByType(entryType: "navigation" | "mark" | "measure" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "paint" | "resource" | "event"): Promise<import("./utils").Entry[]>;
export type Entry = {
    entryType: string;
    toJSON: () => any;
    name: string;
    startTime: number;
    duration: number;
    /**
     * first-input
     */
    detail?: any;
    processingStart: number;
    /**
     * largest-contentful-paint
     */
    processingEnd: number;
    element: HTMLElement;
    size: number;
    renderTime: number;
    /**
     * layout-shift
     */
    loadTime: number;
    value: number;
    lastInputTime: number;
    /**
     * resource
     */
    hadRecentInput: boolean;
    initiatorType: string;
    transferSize: number;
    encodedBodySize: number;
    /**
     * navigation
     */
    decodedBodySize: number;
    type: string;
    domContentLoadedEventEnd: number;
    responseStart: number;
    /**
     * element
     */
    loadEventEnd: number;
    identifier: string;
    intersectionRect: DOMRectReadOnly;
};
export type EntryType = "navigation" | "mark" | "measure" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "paint" | "resource" | "event";
export type ObserverOpts = "navigation" | "mark" | "measure" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "paint" | "resource" | "event" | {
    type: "navigation" | "mark" | "measure" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "paint" | "resource" | "event";
    buffered?: boolean | undefined;
};
export type ObserverCallback = (entries: import("./utils").Entry[], observer: PerformanceObserver) => any;
