/**
 * Create a custom performance mark with `markName` name.
 * https://developer.mozilla.org/en-US/docs/Web/API/Performance/mark
 *
 * @param {string} markName
 * @param {object} [markOptions]
 */
export function mark(markName: string, markOptions?: any): {
    entryType: string;
    name: string;
    startTime: number;
    detail: any;
} | null;
/**
 * Create performance measurement `measureName` between marks, the navigation start time, or `startMarkName`.
 * https://developer.mozilla.org/en-US/docs/Web/API/Performance/measure
 *
 * @param {string} measureName
 * @param {string | object} [startOrMeasureOptions]
 * @param {string} [endMark]
 */
export function measure(measureName: string, startOrMeasureOptions?: any, endMark?: string | undefined): {
    entryType: string;
    name: string;
    startTime: number;
    duration: number;
    detail: any;
} | null;
/**
 * Get the time elapsed since the session start.
 *
 * https://developer.mozilla.org/en-US/docs/Web/API/Performance/now
 */
export function now(): number;
/**
 * Start time measurement.
 * It's similar to console.time(label).
 *
 * @param {string} label
 * @param {string} [startLabel]
 */
export function time(label: string, startLabel?: string | undefined): {
    entryType: string;
    name: string;
    startTime: number;
    detail: any;
} | null;
/**
 * End time measurement.
 * It's similar to console.timeEnd(label).
 *
 * @param {string} label
 * @param {string} [startLabel]
 */
export function timeEnd(label: string, startLabel?: string | undefined): {
    entryType: string;
    name: string;
    startTime: number;
    duration: number;
    detail: any;
} | null;
/**
 * End time measurement after the last paint.
 * It's similar to console.timeEnd(label) but async.
 *
 * @param {string} label
 * @param {string} [startLabel]
 */
export function timeEndPaint(label: string, startLabel?: string | undefined): void;
export let debugTime: boolean;
