/** @param {number} val @param {number} [precision] @return {number} */
export function round(val: number, precision?: number | undefined): number;
/** @param {object} obj */
export function isObject(obj: any): boolean;
/** @param {Element | null} el */
export function getSelector(el: Element | null): string | null;
export const raf: typeof requestAnimationFrame | typeof setTimeout;
export const loc: Location | null;
export const doc: Document | null;
export const PO: {
    new (callback: PerformanceObserverCallback): PerformanceObserver;
    prototype: PerformanceObserver;
    readonly supportedEntryTypes: readonly string[];
} | null;
/** @typedef {{ effectiveType: 'slow-2g' | '2g' | '3g' | '4g', rtt: number, downlink: number }} NetworkInformation */
export const nav: null | (Navigator & {
    deviceMemory: number;
    connection: NetworkInformation;
});
/**
 * @typedef {Object} Entry
 * user timing
 * @prop {string} entryType
 * @prop {() => any} toJSON
 * @prop {string} name
 * @prop {number} startTime
 * @prop {number} duration
 * @prop {object} [detail]
 * first-input
 * @prop {number} processingStart
 * @prop {number} processingEnd
 * largest-contentful-paint
 * @prop {HTMLElement} element
 * @prop {number} size
 * @prop {number} renderTime
 * @prop {number} loadTime
 * layout-shift
 * @prop {number} value
 * @prop {number} lastInputTime
 * @prop {boolean} hadRecentInput
 * resource
 * @prop {string} initiatorType
 * @prop {number} transferSize
 * @prop {number} encodedBodySize
 * @prop {number} decodedBodySize
 * navigation
 * @prop {string} type
 * @prop {number} domContentLoadedEventEnd
 * @prop {number} responseStart
 * @prop {number} loadEventEnd
 * element
 * @prop {string} identifier
 * @prop {DOMRectReadOnly} intersectionRect
 *
 * @typedef {{
 *    timing?: PerformanceTiming,
 *    now?(): number,
 *    clearMarks?(markName: string): void
 *    mark?(markName: string, markOptions?: object): Entry | undefined,
 *    measure?(measureName: string, startOrMeasureOptions?: string | object, endMark?: string): Entry | undefined
 *    getEntriesByType?(entryType: string): Entry[]
 *    getEntriesByName?(name: string): Entry[]
 * }} Perf
 */
export const perf: null | Perf;
export type NetworkInformation = {
    effectiveType: "slow-2g" | "2g" | "3g" | "4g";
    rtt: number;
    downlink: number;
};
/**
 * user timing
 */
export type Entry = {
    entryType: string;
    toJSON: () => any;
    name: string;
    startTime: number;
    duration: number;
    /**
     * first-input
     */
    detail?: any;
    processingStart: number;
    /**
     * largest-contentful-paint
     */
    processingEnd: number;
    element: HTMLElement;
    size: number;
    renderTime: number;
    /**
     * layout-shift
     */
    loadTime: number;
    value: number;
    lastInputTime: number;
    /**
     * resource
     */
    hadRecentInput: boolean;
    initiatorType: string;
    transferSize: number;
    encodedBodySize: number;
    /**
     * navigation
     */
    decodedBodySize: number;
    type: string;
    domContentLoadedEventEnd: number;
    responseStart: number;
    /**
     * element
     */
    loadEventEnd: number;
    identifier: string;
    intersectionRect: DOMRectReadOnly;
};
export type Perf = {
    timing?: PerformanceTiming | undefined;
    now?(): number;
    clearMarks?(markName: string): void;
    mark?(markName: string, markOptions?: any): Entry | undefined;
    measure?(measureName: string, startOrMeasureOptions?: any, endMark?: string | undefined): Entry | undefined;
    getEntriesByType?(entryType: string): Entry[];
    getEntriesByName?(name: string): Entry[];
};
